package java.text;

import java.io.Serializable;

public abstract class Format implements Serializable, Cloneable
{
    private static final long serialVersionUID = -299282585814624189L;
    
    protected Format() {
    }
    
    public final String format(Object o) {
        return this.format(o, new StringBuffer(), new FieldPosition(0)).toString();
    }
    
    public abstract StringBuffer format(Object p0, StringBuffer p1, FieldPosition p2);
    
    public AttributedCharacterIterator formatToCharacterIterator(Object o) {
        return this.createAttributedCharacterIterator(this.format(o));
    }
    
    public abstract Object parseObject(String p0, ParsePosition p1);
    
    public Object parseObject(String s) throws ParseException {
        ParsePosition parsePosition = new ParsePosition(0);
        Object object = this.parseObject(s, parsePosition);
        if (parsePosition.index == 0) {
            throw new ParseException("Format.parseObject(String) failed", parsePosition.errorIndex);
        }
        return object;
    }
    
    public Object clone() {
        try {
            return super.clone();
        }
        catch (CloneNotSupportedException cause) {
            throw new InternalError(cause);
        }
    }
    
    AttributedCharacterIterator createAttributedCharacterIterator(String s) {
        return new AttributedString(s).getIterator();
    }
    
    AttributedCharacterIterator createAttributedCharacterIterator(AttributedCharacterIterator[] array) {
        return new AttributedString(array).getIterator();
    }
    
    AttributedCharacterIterator createAttributedCharacterIterator(String s, AttributedCharacterIterator.Attribute attribute, Object o) {
        AttributedString attributedString = new AttributedString(s);
        attributedString.addAttribute(attribute, o);
        return attributedString.getIterator();
    }
    
    AttributedCharacterIterator createAttributedCharacterIterator(AttributedCharacterIterator attributedCharacterIterator, AttributedCharacterIterator.Attribute attribute, Object o) {
        AttributedString attributedString = new AttributedString(attributedCharacterIterator);
        attributedString.addAttribute(attribute, o);
        return attributedString.getIterator();
    }
    
    public static class Field extends AttributedCharacterIterator.Attribute
    {
        private static final long serialVersionUID = 276966692217360283L;
        
        protected Field(String s) {
            super(s);
        }
    }
    
    interface FieldDelegate
    {
        public abstract void formatted(Format.Field p0, Object p1, int p2, int p3, StringBuffer p4);
        
        public abstract void formatted(int p0, Format.Field p1, Object p2, int p3, int p4, StringBuffer p5);
    }
}
